/**
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 * 
 * You should have find a copy of NFSChina License. If not, please contact us 
 * by email <os_support@nfschina.com>  
 * 
**/
#ifndef __NFSPIN_H__
#define __NFSPIN_H__

#include <stdio.h>
#include <syslog.h>
#include <gmssl/x509_crl.h>
#include <gmssl/x509_ext.h>
#include <gmssl/oid.h>
#include <gmssl/x509_alg.h>
#include <gmssl/x509.h>
#include <gmssl/rand.h>
#include <gmssl/error.h>


#define BACKSPACE 0X08   //删除的asccll码值

#define  ROOTUSER   "root"          //0
#define  SECUSER    "secadm"        //1
#define  AUDITUSER  "auditadm"      //2

#define KEYUSERFILE  "NFSUSERFILE"
#define KEYPAMFILE   "NFSPAMFILE"

//safe box
#define KEYSAFEBOX   "NFSSAFEBOX"

//datats
#define KEYDATATSPUBK1   "NFSDATATSPUBK1"
#define KEYDATATSPRIK1   "NFSDATATSPRIK1"
#define KEYDATATSPUBK2   "NFSDATATSPUBK2"
#define KEYDATATSPRIK2   "NFSDATATSPRIK2"

#define NFSSECCERT_NFSSECD     "nfssecd.dat"
#define NFSSECCERT_NFSSECD_PWD "nfssecd.dat.pwd"

#define NFSSECCERT_SECDAPI     "secdapi.dat"
#define NFSSECCERT_SECDAPI_PWD "secdapi.dat.pwd"

#define NFSSECCERT_DATATS      "datats.pem"
#define NFSSECCERT_DATATS_PWD  "datats.pem.pwd"


enum e_scert{
	cert_nfssecd = 0,//nfssecd.dat
	cert_secdapi = 1,//secdapi.dat
	cert_datats = 2,//datats.pem
};



#ifdef __cplusplus
extern "C" {
#endif
//遍历设备
int nfsEnumDev(char **devlist, unsigned int *pulSize);

int nfsOpenDev_mult(char *devname);

//打开ukey设备
int nfsOpenDev();

//读取PIN
int nfsReadPIN();

//校验pin
int nfsCheckPIN( char *pin, unsigned int *numRetry);

//关闭ukey设备
int nfsCloseDev();

//获取ukey prik文件
int nfsGetFileContent(enum e_scert num, SM2_KEY *pst_sm2_privateKey);


//获取用户
int nfsGetUser(char *name);

//设置用户
int nfsSetUser(int number, char *strname);

int nfsSetFile(char *ukeyfilename, unsigned char *pdata, int datalen);

int nfsGetFile(char *ukeyfilename, unsigned char **pdata, int *datalen);

int nfsGetAllFileName();

int nfsDelFile(char * filename);

int nfsGetPwdFileForNfssec(char *filename);

//siji 证书链校验
int certChainVerify(char *nextpempath, char *rootpempath);

//siji safebox
int nfsSetFileNotDel(char *ukeyfilename, unsigned char *pdata, int datalen);

//siji datats
int nfsGetFilePubkey(char *ukeyfilename, SM2_KEY *pubkey);
int nfsGetFilePrikey(char *ukeyfilename, SM2_KEY *prikey);

#ifdef __cplusplus
}
#endif


#endif
